@@ -2,16 +2,25 @@ use std::convert::TryFrom;
 use std::ptr;
 
 use super::*;
-use crate::{check_status, sys, Result};
+use crate::{bindgen_runtime::TypeName, check_status, sys, Result};
 
 #[derive(Clone, Copy)]
-pub struct JsBigint {
+pub struct JsBigInt {
   pub(crate) raw: Value,
   pub word_count: usize,
 }
 
-impl JsBigint {
-  #[inline]
+impl TypeName for JsBigInt {
+  fn type_name() -> &'static str {
+    "BigInt"
+  }
+
+  fn value_type() -> ValueType {
+    ValueType::BigInt
+  }
+}
+
+impl JsBigInt {
   pub(crate) fn from_raw_unchecked(
     env: sys::napi_env,
     value: sys::napi_value,
@@ -27,12 +36,10 @@ impl JsBigint {
     }
   }
 
-  #[inline]
   pub fn into_unknown(self) -> Result<JsUnknown> {
     unsafe { JsUnknown::from_raw(self.raw.env, self.raw.value) }
   }
 
-  #[inline]
   pub fn coerce_to_number(self) -> Result<JsNumber> {
     let mut new_raw_value = ptr::null_mut();
     check_status!(unsafe {
@@ -45,7 +52,6 @@ impl JsBigint {
     }))
   }
 
-  #[inline]
   pub fn coerce_to_string(self) -> Result<JsString> {
     let mut new_raw_value = ptr::null_mut();
     check_status!(unsafe {
@@ -57,7 +63,7 @@ impl JsBigint {
       value_type: ValueType::String,
     }))
   }
-  #[inline]
+
   pub fn coerce_to_object(self) -> Result<JsObject> {
     let mut new_raw_value = ptr::null_mut();
     check_status!(unsafe {
@@ -70,50 +76,42 @@ impl JsBigint {
     }))
   }
 
-  #[inline]
-  #[cfg(feature = "napi5")]
   pub fn is_date(&self) -> Result<bool> {
     let mut is_date = true;
     check_status!(unsafe { sys::napi_is_date(self.raw.env, self.raw.value, &mut is_date) })?;
     Ok(is_date)
   }
 
-  #[inline]
   pub fn is_error(&self) -> Result<bool> {
     let mut result = false;
     check_status!(unsafe { sys::napi_is_error(self.raw.env, self.raw.value, &mut result) })?;
     Ok(result)
   }
 
-  #[inline]
   pub fn is_typedarray(&self) -> Result<bool> {
     let mut result = false;
     check_status!(unsafe { sys::napi_is_typedarray(self.raw.env, self.raw.value, &mut result) })?;
     Ok(result)
   }
 
-  #[inline]
   pub fn is_dataview(&self) -> Result<bool> {
     let mut result = false;
     check_status!(unsafe { sys::napi_is_dataview(self.raw.env, self.raw.value, &mut result) })?;
     Ok(result)
   }
 
-  #[inline]
   pub fn is_array(&self) -> Result<bool> {
     let mut is_array = false;
     check_status!(unsafe { sys::napi_is_array(self.raw.env, self.raw.value, &mut is_array) })?;
     Ok(is_array)
   }
 
-  #[inline]
   pub fn is_buffer(&self) -> Result<bool> {
     let mut is_buffer = false;
     check_status!(unsafe { sys::napi_is_buffer(self.raw.env, self.raw.value, &mut is_buffer) })?;
     Ok(is_buffer)
   }
 
-  #[inline]
   pub fn instanceof<Constructor: NapiRaw>(&self, constructor: Constructor) -> Result<bool> {
     let mut result = false;
     check_status!(unsafe {
@@ -123,33 +121,35 @@ impl JsBigint {
   }
 }
 
-impl NapiRaw for JsBigint {
+impl NapiRaw for JsBigInt {
   unsafe fn raw(&self) -> sys::napi_value {
     self.raw.value
   }
 }
 
-impl<'env> NapiRaw for &'env JsBigint {
+impl<'env> NapiRaw for &'env JsBigInt {
   unsafe fn raw(&self) -> sys::napi_value {
     self.raw.value
   }
 }
 
-impl NapiValue for JsBigint {
+impl NapiValue for JsBigInt {
   unsafe fn from_raw(env: sys::napi_env, value: sys::napi_value) -> Result<Self> {
     let mut word_count = 0usize;
-    check_status!(sys::napi_get_value_bigint_words(
-      env,
-      value,
-      ptr::null_mut(),
-      &mut word_count,
-      ptr::null_mut(),
-    ))?;
-    Ok(JsBigint {
+    check_status!(unsafe {
+      sys::napi_get_value_bigint_words(
+        env,
+        value,
+        ptr::null_mut(),
+        &mut word_count,
+        ptr::null_mut(),
+      )
+    })?;
+    Ok(JsBigInt {
       raw: Value {
         env,
         value,
-        value_type: ValueType::Bigint,
+        value_type: ValueType::BigInt,
       },
       word_count,
     })
@@ -157,22 +157,24 @@ impl NapiValue for JsBigint {
 
   unsafe fn from_raw_unchecked(env: sys::napi_env, value: sys::napi_value) -> Self {
     let mut word_count = 0usize;
-    let status = sys::napi_get_value_bigint_words(
-      env,
-      value,
-      ptr::null_mut(),
-      &mut word_count,
-      ptr::null_mut(),
-    );
+    let status = unsafe {
+      sys::napi_get_value_bigint_words(
+        env,
+        value,
+        ptr::null_mut(),
+        &mut word_count,
+        ptr::null_mut(),
+      )
+    };
     debug_assert!(
       Status::from(status) == Status::Ok,
       "napi_get_value_bigint_words failed"
     );
-    JsBigint {
+    JsBigInt {
       raw: Value {
         env,
         value,
-        value_type: ValueType::Bigint,
+        value_type: ValueType::BigInt,
       },
       word_count,
     }
@@ -180,26 +182,25 @@ impl NapiValue for JsBigint {
 }
 
 /// The BigInt will be converted losslessly when the value is over what an int64 could hold.
-impl TryFrom<JsBigint> for i64 {
+impl TryFrom<JsBigInt> for i64 {
   type Error = Error;
 
-  fn try_from(value: JsBigint) -> Result<i64> {
+  fn try_from(value: JsBigInt) -> Result<i64> {
     value.get_i64().map(|(v, _)| v)
   }
 }
 
 /// The BigInt will be converted losslessly when the value is over what an uint64 could hold.
-impl TryFrom<JsBigint> for u64 {
+impl TryFrom<JsBigInt> for u64 {
   type Error = Error;
 
-  fn try_from(value: JsBigint) -> Result<u64> {
+  fn try_from(value: JsBigInt) -> Result<u64> {
     value.get_u64().map(|(v, _)| v)
   }
 }
 
-impl JsBigint {
-  /// https://nodejs.org/api/n-api.html#n_api_napi_get_value_bigint_words
-  #[inline]
+impl JsBigInt {
+  /// <https://nodejs.org/api/n-api.html#n_api_napi_get_value_bigint_words>
   pub fn get_words(&mut self) -> Result<(bool, Vec<u64>)> {
     let mut words: Vec<u64> = Vec::with_capacity(self.word_count as usize);
     let word_count = &mut self.word_count;
@@ -221,28 +222,25 @@ impl JsBigint {
     Ok((sign_bit == 1, words))
   }
 
-  #[inline]
   pub fn get_u64(&self) -> Result<(u64, bool)> {
     let mut val: u64 = 0;
-    let mut loss = false;
+    let mut lossless = false;
     check_status!(unsafe {
-      sys::napi_get_value_bigint_uint64(self.raw.env, self.raw.value, &mut val, &mut loss)
+      sys::napi_get_value_bigint_uint64(self.raw.env, self.raw.value, &mut val, &mut lossless)
     })?;
 
-    Ok((val, loss))
+    Ok((val, lossless))
   }
 
-  #[inline]
   pub fn get_i64(&self) -> Result<(i64, bool)> {
     let mut val: i64 = 0;
-    let mut loss: bool = false;
+    let mut lossless: bool = false;
     check_status!(unsafe {
-      sys::napi_get_value_bigint_int64(self.raw.env, self.raw.value, &mut val, &mut loss)
+      sys::napi_get_value_bigint_int64(self.raw.env, self.raw.value, &mut val, &mut lossless)
     })?;
-    Ok((val, loss))
+    Ok((val, lossless))
   }
 
-  #[inline]
   pub fn get_i128(&mut self) -> Result<(i128, bool)> {
     let (signed, words) = self.get_words()?;
     let len = words.len();
@@ -254,7 +252,6 @@ impl JsBigint {
     Ok((val, len > 2))
   }
 
-  #[inline]
   pub fn get_u128(&mut self) -> Result<(bool, u128, bool)> {
     let (signed, words) = self.get_words()?;
     let len = words.len();
